clear all
%Constant variables

%Free stream velocity
V_inf = 15; % [m/s]

%Wake decay constant
k = 0.05; 

%Turbine diameter
D0 = 80; % [m]
%Turbine swept area
Area = pi*(D0/2)^2;

%Air density at 15C and at sea level
rho = 1.225; % [kg/m^3]

%Entrainment constant
%alpha = 0.1; %From Jensen, "A note on Wind Generator Interaction" alpha*x + D0/2 


%Rated power(at 15m/s)
% P_test1 = 1/2*pi*(122/2)^2*rho*V_inf^3*0.13;
% P_test2 = 1/2*pi*(80/2)^2*rho*V_inf^3*0.22;
%::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
%Vind speed deficit (at turbine 2 from turbine 1)
%deltaV21 =V_inf * (1 - sqrt(1 - C_T1)) * (D0/(D0 + 2*k*x21))^2;
%%
%********SIMULATION CONFIGURATION*********

% The WindDecrease has been used to set the value of C_P. Easier to set the
% value of C_P manually... :)



% NO YAW: 8.3722  YAW7: 9.2477  YAW10: 9.9358

WindDecrease1 = 0.86695; %C_P = 0.4
WindDecrease2 = 0.86695; %C_P = 0.4
WindDecrease3 = 0.86695; %C_P = 0.4

% NO YAW: 8.0128    YAW7: 8.6807  YAW10: 9.1724
% WindDecrease1 = 0.9093; %C_P = 0.3
% WindDecrease2 = 0.88937; %C_P = 0.35
% WindDecrease3 = 0.86695; %C_P = 0.4


% NO YAW: 8.4149  YAW7: 9.1135  YAW10: 9.6259
% WindDecrease1 = 0.9093; %C_P = 0.3
% WindDecrease2 = 0.86695; %C_P = 0.4
% WindDecrease3 = 0.86695; %C_P = 0.4


% % NO YAW: 8.4156  YAW7: 9.0332 YAW10:
% WindDecrease1 = 0.9237; %C_P = 0.2x
% WindDecrease2 = 0.86695; %C_P = 0.4
% WindDecrease3 = 0.86695; %C_P = 0.4

% NO YAW: 8.4156  YAW7: 9.0332
% WindDecrease1 = 0.9200; %C_P = 0.2x
% WindDecrease2 = 0.86695; %C_P = 0.4
% WindDecrease3 = 0.86695; %C_P = 0.4



t = 1:1:1000; %Simulation duration

%Yaw angle vector pre allocating
theta = zeros(length(t),1);

for j = 2:1:1000
   theta(j) = theta(j-1) + 0.02; %From 0 to 20deg
end

% % THETA 7 DEG
% theta(1) = 7;
% for j = 2:1:1000
%     theta(j) = 7;
% end

% THETA 7 DEG
% theta(1) = 10;
% for j = 2:1:1000
%     theta(j) = 10;
% end


%%
%Turbine 1%

%Position
x11 = 0;
y11 = 0;

V_d1 = V_inf*WindDecrease1; %Decrease in wind speed at the rotor plane

%Axial induction factor
a1 = (V_inf - V_d1)/V_inf;

%Thrust coefficient, as function of Axial induction factor
C_T1 = 4*a1*(1-a1);

%Power coefficient
C_P1 = 4*a1*(1-a1)^2; %Easier to set CP manually :)

%Rated power(at 15m/s)
P_1 = 1/2*pi*(D0/2)^2*rho*V_inf^3*C_P1;

%%
%Turbine 2%

%Position, center of the turbine.
x21 = 300;
y21 = 0;
%Top and bottom coordinates of the rotor
topT2 = y21+(D0/2);
botT2 = y21-(D0/2);


V_d2 = V_inf*WindDecrease2; %Decrease in wind speed at the rotor plane

%Axial induction factor
a2 = (V_inf - V_d2)/V_inf;

%Thrust coefficient, as function of Axial induction factor
C_T2 = 4*a1*(1-a2);

%Power coefficient
C_P2 = 4*a2*(1-a2)^2;

%Rated power(at 15m/s)
P_2 = 1/2*pi*(D0/2)^2*rho*V_inf^3*C_P2;
%% 
%Overlap: turbine 2 

h21 = k*x21;

degTriangle1 = atan(h21/x21);
%     theta_new = deg21 + theta;

h32 = k*x32;

degTriangle2 = atan(h32/x32);

%%
%Turbine 3%

%Position, center of the turbine, relative to turbine 1.
x31 = 600;
y31 = 0;

%Position, center of the turbine, relative to turbine 2.
x32 = x31-x21;
y32 = y31-y21;
%:::::::::::::::::::::::::::::::::::::::::::::::::::::::

V_d3 = V_inf*WindDecrease3; %Decrease in wind speed at the rotor plane

%Axial induction factor
a3 = (V_inf - V_d3)/V_inf;

%Thrust coefficient, as function of Axial induction factor
C_T3 = 4*a3*(1-a3);

%Power coefficient
C_P3 = 4*a3*(1-a3)^2;

%Rated power(at 15m/s)
P_3 = 1/2*pi*(D0/2)^2*rho*V_inf^3*C_P3;










